summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/kpilotlink.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/kpilotlink.cc')
-rw-r--r--kpilot/lib/kpilotlink.cc34
1 files changed, 17 insertions, 17 deletions
diff --git a/kpilot/lib/kpilotlink.cc b/kpilot/lib/kpilotlink.cc
index 9c0b85ee..da85d489 100644
--- a/kpilot/lib/kpilotlink.cc
+++ b/kpilot/lib/kpilotlink.cc
@@ -47,10 +47,10 @@
#include <pi-file.h>
#include <pi-buffer.h>
-#include <qdir.h>
-#include <qtimer.h>
-#include <qdatetime.h>
-#include <qthread.h>
+#include <tqdir.h>
+#include <tqtimer.h>
+#include <tqdatetime.h>
+#include <tqthread.h>
#include <kconfig.h>
#include <kmessagebox.h>
@@ -74,7 +74,7 @@ class TickleThread : public QThread
{
public:
TickleThread(KPilotLink *d, bool *done, int timeout) :
- QThread(),
+ TQThread(),
fHandle(d),
fDone(done),
fTimeout(timeout)
@@ -108,14 +108,14 @@ void TickleThread::run()
while (!(*fDone))
{
- QThread::msleep(1000/ChecksPerSecond);
+ TQThread::msleep(1000/ChecksPerSecond);
if (!(--subseconds))
{
if (timeout)
{
if (!(--timeout))
{
- QApplication::postEvent(fHandle, new QEvent(static_cast<QEvent::Type>(KPilotLink::EventTickleTimeout)));
+ TQApplication::postEvent(fHandle, new TQEvent(static_cast<TQEvent::Type>(KPilotLink::EventTickleTimeout)));
break;
}
}
@@ -137,9 +137,9 @@ void TickleThread::run()
-KPilotLink::KPilotLink( QObject *parent, const char *name ) :
- QObject( parent, name ),
- fPilotPath(QString::null),
+KPilotLink::KPilotLink( TQObject *parent, const char *name ) :
+ TQObject( parent, name ),
+ fPilotPath(TQString::null),
fPilotUser(0L),
fPilotSysInfo(0L),
fTickleDone(true),
@@ -169,7 +169,7 @@ KPilotLink::~KPilotLink()
KPILOT_DELETE(fPilotSysInfo);
}
/* virtual */ bool KPilotLink::event(QEvent *e)
{
if ((int)e->type() == EventTickleTimeout)
{
@@ -177,7 +177,7 @@ KPilotLink::~KPilotLink()
emit timeout();
return true;
}
- else return QObject::event(e);
+ else return TQObject::event(e);
}
/*
@@ -218,30 +218,30 @@ void KPilotLink::stopTickle()
}
}
-unsigned int KPilotLink::installFiles(const QStringList & l, const bool deleteFiles)
+unsigned int KPilotLink::installFiles(const TQStringList & l, const bool deleteFiles)
{
FUNCTIONSETUP;
- QStringList::ConstIterator i,e;
+ TQStringList::ConstIterator i,e;
unsigned int k = 0;
unsigned int n = 0;
unsigned int total = l.count();
for (i = l.begin(), e = l.end(); i != e; ++i)
{
- emit logProgress(QString::null,
+ emit logProgress(TQString::null,
(int) ((100.0 / total) * (float) n));
if (installFile(*i, deleteFiles))
k++;
n++;
}
- emit logProgress(QString::null, 100);
+ emit logProgress(TQString::null, 100);
return k;
}
-void KPilotLink::addSyncLogEntry(const QString & entry, bool log)
+void KPilotLink::addSyncLogEntry(const TQString & entry, bool log)
{
FUNCTIONSETUP;
if (entry.isEmpty()) return;
@@ -169,7 +169,7 @@ KPilotLink::~KPilotLink()
KPILOT_DELETE(fPilotSysInfo);
}
-/* virtual */ bool KPilotLink::event(QEvent *e)
+/* virtual */ bool KPilotLink::event(TQEvent *e)
{
if ((int)e->type() == EventTickleTimeout)